| Title: | Integration of 'dplyr' and 'ggplot2' with 'EdSurvey' |
|---|---|
| Description: | Takes objects of class edsurvey.data.frame and converts them to a data.frame within the calling environment of 'dplyr' and 'ggplot2' functions. Additionally, for plotting with 'ggplot2', users can map aesthetics to subject scales and all plausible values will be used. This package supports student level data; to work with school or teacher level data, see '?EdSurvey::getData'. |
| Authors: | Paul Bailey [cre, ctb] (ORCID: <https://orcid.org/0000-0003-0989-8729>), Blue Webb [aut] (ORCID: <https://orcid.org/0009-0004-4080-9864>), Tom Fink [ctb] (ORCID: <https://orcid.org/0009-0003-9308-2833>) |
| Maintainer: | Paul Bailey <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.4 |
| Built: | 2026-06-02 09:52:03 UTC |
| Source: | https://github.com/cran/tidyEdSurvey |
edsurvey.data.frame to Search PathImplements attach for an edsurvey.data.frame or a light.edsurvey.data.frame by attaching student level variables to the search path
attach( what, pos = 2L, name = deparse1(substitute(what), backtick = FALSE), warn.conflicts = TRUE )attach( what, pos = 2L, name = deparse1(substitute(what), backtick = FALSE), warn.conflicts = TRUE )
what |
equivalent to 'what' in |
pos |
equivalent to 'pos' in |
name |
equivalent to 'name' in |
warn.conflicts |
equivalent to 'warn.conflicts' in |
Because attach is a standard generic function that does not use method dispatch, we set this function as generic,
which means it overwrites base::attach on loading. If the object to attach is not an edsurvey.data.frame or a light.edsurvey.data.frame,
the function will revert to the standard base method.
the environment is returned invisibly with a "name" attribute
Blue Webb